summaryrefslogtreecommitdiffstats
path: root/sys/contrib/dev/acpica/include/actbl2.h
diff options
context:
space:
mode:
Diffstat (limited to 'sys/contrib/dev/acpica/include/actbl2.h')
-rw-r--r--sys/contrib/dev/acpica/include/actbl2.h28
1 files changed, 25 insertions, 3 deletions
diff --git a/sys/contrib/dev/acpica/include/actbl2.h b/sys/contrib/dev/acpica/include/actbl2.h
index 2d2d5ca..49b9578 100644
--- a/sys/contrib/dev/acpica/include/actbl2.h
+++ b/sys/contrib/dev/acpica/include/actbl2.h
@@ -5,7 +5,7 @@
*****************************************************************************/
/*
- * Copyright (C) 2000 - 2012, Intel Corp.
+ * Copyright (C) 2000 - 2013, Intel Corp.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -285,6 +285,7 @@ typedef struct acpi_table_csrt
} ACPI_TABLE_CSRT;
+
/* Resource Group subtable */
typedef struct acpi_csrt_group
@@ -296,12 +297,33 @@ typedef struct acpi_csrt_group
UINT16 SubdeviceId;
UINT16 Revision;
UINT16 Reserved;
- UINT32 InfoLength;
+ UINT32 SharedInfoLength;
- /* Shared data (length = InfoLength) immediately follows */
+ /* Shared data immediately follows (Length = SharedInfoLength) */
} ACPI_CSRT_GROUP;
+/* Shared Info subtable */
+
+typedef struct acpi_csrt_shared_info
+{
+ UINT16 MajorVersion;
+ UINT16 MinorVersion;
+ UINT32 MmioBaseLow;
+ UINT32 MmioBaseHigh;
+ UINT32 GsiInterrupt;
+ UINT8 InterruptPolarity;
+ UINT8 InterruptMode;
+ UINT8 NumChannels;
+ UINT8 DmaAddressWidth;
+ UINT16 BaseRequestLine;
+ UINT16 NumHandshakeSignals;
+ UINT32 MaxBlockSize;
+
+ /* Resource descriptors immediately follow (Length = Group Length - SharedInfoLength) */
+
+} ACPI_CSRT_SHARED_INFO;
+
/* Resource Descriptor subtable */
typedef struct acpi_csrt_descriptor
OpenPOWER on IntegriCloud